import React, { memo, Fragment, useEffect } from 'react';
import styles from './ContentList.less';
import NativeHook from '@/utils/NativeHook';
import { IPropsList, ListItem } from '../api';
import { getQueryString } from '../../../utils/Url';

const ContentList = (props: IPropsList) => {
  const showStyle: number = Number(getQueryString('showStyle'));
  const { dataList } = props;
  const goToRoom = (roomId: string) => {
    if (roomId) {
      NativeHook.go.chatRoom({ roomId });
    }
  };
  useEffect(() => {
    NativeHook.init();
    return () => {
      NativeHook.destroy();
    };
  }, []);
  const unitChange = (value: number) => {
    let num = value > 9999 ? (value / 10000).toFixed(2) + '万' : value;
    return num;
  };
  return (
    <Fragment>
      {dataList.length == 0 ? <div className={styles.no_content}>暂无数据</div> : ''}
      <div className={styles.box_ranks}>
        {dataList &&
          dataList.map((item: ListItem, i: number) => {
            return (
              <Fragment key={item.rankNo}>
                {i < 3 ? (
                  <div className={styles.item}>
                    <div className={styles.photo_bg} onClick={() => goToRoom(item.roomId)}>
                      <div className={styles.photo} style={{ backgroundImage: `url(${item.roomCover})` }}></div>
                    </div>
                    <div className={styles.name} onClick={() => goToRoom(item.roomId)}>
                      {item.roomName}
                    </div>
                    <div className={styles.tips}>{i == 0 ? '第一名' : '距前一名'}</div>
                    {i > 0 && <div className={styles.num}>{unitChange(Number(item.diffValue))}</div>}
                  </div>
                ) : (
                  ''
                )}
              </Fragment>
            );
          })}
      </div>
      {dataList.length > 3 ? (
        <div className={styles.warp_list} style={{ height: showStyle == 0 ? 'auto' : '', paddingBottom: showStyle == 0 ? '20px' : '' }}>
          <ul className={styles.box_list}>
            {dataList &&
              dataList.map((item: ListItem, i: number) => {
                return (
                  <Fragment key={item.rankNo}>
                    {i >= 3 && (
                      <li className={styles.item}>
                        <div className={styles.item_left}>
                          <span className={styles.rankNo}>{item.rankNo}</span>
                          <div
                            className={styles.photo}
                            style={{ backgroundImage: `url(${item.roomCover})` }}
                            onClick={() => goToRoom(item.roomId)}
                          ></div>
                          <span className={styles.name} onClick={() => goToRoom(item.roomId)}>
                            {item.roomName}
                          </span>
                        </div>
                        <div className={styles.item_right}>
                          <span className={styles.tips}>距前一名</span>
                          <span className={styles.num}>{unitChange(Number(item.diffValue))}</span>
                        </div>
                      </li>
                    )}
                  </Fragment>
                );
              })}
          </ul>
          {dataList.length >= 20 ? <p className={styles.footer_tips}>仅显示前20名的房间</p> : ''}
        </div>
      ) : (
        ''
      )}
    </Fragment>
  );
};
export default memo(ContentList);
