import React, { useEffect, useState,Fragment } from 'react';
import styles from './Message.less';
import NativeHook from '@/utils/NativeHook';
import { Loading } from 'antd-mobile';
import { CloseOutline } from 'antd-mobile-icons';
import ImageZoom from './components/ImageZoom';
import RoomBlock from './components/RoomBlock';
import AnchorBlock from './components/AnchorBlock';
import HeaderBlock from './components/HeaderBlock';
import BackHeader from './components/BackHeader';
import { getFeedActivityInfo } from './api'

export default function Message(props) {
  const { showStyle,infoId } = props.location.query;
  const [loading,setLoading] = useState(true)
  const [pageInfor,setPageInfor] = useState({})
  const [pageContent,setPageContent] = useState([])
  useEffect(() => {
    NativeHook.init();
    getFeedActivityInfos();
    return () => {
      NativeHook.destroy()
    }
  }, []);
  const onClose = () => {
    console.log('关闭')
    NativeHook.call.close();
  }
  const getFeedActivityInfos = async () => {
    try {
      const params = {
        infoId: infoId
      }
      const { success, data } = await getFeedActivityInfo(params);
      if (success && data) {
        setLoading(false)
        const { content } = data;
        document.title = data.title || '资讯';
        createiframe();
        if (Object.getOwnPropertyNames(data) != 0 ) {
          setPageInfor(data);
          setPageContent(content);
        }
      }
    } catch (error) {
      console.log(error);
    }
  }
  // 通过后台数据动态修改页面的title
  const createiframe = ()=>{
    let iframe = document.createElement('iframe');
    iframe.src = '';
    iframe.style.display = 'none';
    let fn = function () {
      setTimeout(function () {
        iframe.removeEventListener('load', fn);
        document.body.removeChild(iframe);
      }, 0);
    };
    iframe.addEventListener('load', fn);
    document.body.appendChild(iframe);
  }


  return (
    <Fragment>
      {
        loading ?
        <div style={{ color: '#666' }} className={styles.loading_warp}>
          <Loading color='currentColor' />
          <span>正在加载,请等待</span>
        </div> :

        Object.getOwnPropertyNames(pageInfor) == 0 || pageInfor.status == 0 ? <div className={styles.no_content}>内容已失效~~~</div> :

        showStyle == 2 ?
        // 弹窗
        <div className={styles.popup_wrap}>
          <div className={styles.bg} onClick={onClose}></div>
          <div className={styles.box}>
            <div className={styles.close} onClick={onClose}>
              {/* <Icon className={styles.close_icon} type="cross" /> */}
              <CloseOutline fontSize={24}/>
            </div>
            <div className={styles.title}>{pageInfor.title}</div>
            <div className={styles.content}>
              {
                pageContent.length > 0 && pageContent.map((item,i) =>{
                  return(
                    <p>{item.value}</p>
                  )
                })
              }
            </div>
          </div>
        </div>
        :
        // 全屏跟半屏 1:半屏 0:全屏 2:弹窗
        <Fragment>
          {
            showStyle == 1 && <BackHeader {...props} title={pageInfor.title}></BackHeader>
          }
          <div className={styles.home_wrap}>
            {/* 如果是资讯则展示顶部标题 */}
            {
              pageInfor.type == 0 ? <HeaderBlock headerInfor={pageInfor}></HeaderBlock> : null
            }
            {
              pageContent.length > 0 && pageContent.map((item,i) =>{
                return(
                  <Fragment key={i}>
                    {
                      item.type == 1 ?
                      <ImageZoom src={item.value} />
                      : item.type == 2 ?
                      <RoomBlock roomInfor={item}></RoomBlock>
                      : item.type == 3 ?
                      <AnchorBlock anchorInfor={item}></AnchorBlock>
                      : item.type == 4 ?
                      <div className={styles.text_warp}><a href={item.link}>{item.title}</a></div>
                      : <div className={styles.text_warp}>{item.value}</div>
                    }
                  </Fragment>
                )
              })
            }
          </div>
        </Fragment>
      }
    </Fragment>
  )
}
