import NativeHook from './NativeHook';

export type Result<T> = {
  code: number;
  msg: string;
  data: T;
  success: boolean;
};

type NativeRequestParams<P> = {
  /**接口地址 '/api-app/v1/activity/getRecharge'*/
  api: string;
  /**传参 */
  params?: P;
  /**是否提示错误信息默认false */
  isDialogShow?: boolean;
  /**获取方式 */
  method: 'getData' | 'postData';

  [propsName: string]: any;
};

/**Native Promise Request */
export function NativeRequest<P, R>(requestParams: NativeRequestParams<P>): Promise<R> {
  const { api, params = {}, isDialogShow = false, method = 'getData' } = requestParams;
  return new Promise((resolve, reject) => {
    NativeHook.call[method]({ api, params, isDialogShow }, (res: Result<R>) => {
      if (res.success) {
        resolve(res.data);
      } else {
        reject(res);
      }
    });
  });
}

// /**获取充值活动 */
// type GetRechargeParams = { activityId: string };
// export const getRecharge = (params: GetRechargeParams) => {
//   return NativeRequest<GetRechargeParams, ResultInfo>({
//     api: '/api-app/v1/activity/getRecharge',
//     params,
//     method: 'getData',
//   });
// };

// //使用方法一结合useRequest
// const { data: info, loading: loading1, run: fetchRecharge } = useRequest(getRecharge, {
//   defaultParams: [{ activityId: '123' }],
// });

// //使用方法二，直接async await
// const fun = async()=> {
//   const res = await getRecharge({ activityId: '123' })
// }

